<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Stretch</name>
    <message>
        <location filename="../Stretch.js" line="+78"/>
        <source>Reference point</source>
        <translation>Referenzpunkt</translation>
    </message>
    <message>
        <location filename="../StretchInit.js" line="+2"/>
        <source>&amp;Stretch</source>
        <translation>&amp;Strecken</translation>
    </message>
    <message>
        <location filename="../Stretch.js" line="-19"/>
        <source>First corner</source>
        <translation>Erster Eckpunkt</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Second corner</source>
        <translation>Zweiter Eckpunkt</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Target point</source>
        <translation>Zielpunkt</translation>
    </message>
    <message>
        <location line="+138"/>
        <source>No selected entities in given range</source>
        <translation>Keine ausgewählten Objekte im angegebenen Bereich</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No entities in given range</source>
        <translation>Keine Objekte im angegebenen Bereich</translation>
    </message>
</context>
</TS>
